@@ -433,13 +433,13 @@ void MlevelNodeBisectionMultiple(CtrlType *ctrl, GraphType *graph, int *tpwgts,
     bestwhere = idxmalloc(cnvtxs, "MlevelNodeBisection2: bestwhere");
     mincut = nvtxs;
 
-    for (i=ctrl->nseps; i>0; i--) {
+    for (i=0; i<ctrl->nseps; i++) {
       ctrl->CType += 20; /* This is a hack. Look at coarsen.c */
       MlevelNodeBisection(ctrl, cgraph, tpwgts, ubfactor);
 
       /* printf("%5d ", cgraph->mincut); */
 
-      if (cgraph->mincut < mincut) {
+      if (i == 0 || cgraph->mincut < mincut) {
         mincut = cgraph->mincut;
         idxcopy(cnvtxs, cgraph->where, bestwhere);
       }
