@@ -19,7 +19,7 @@
 /*************************************************************************
 * This function performs k-way refinement
 **************************************************************************/
-void Moc_KWayFM(CtrlType *ctrl, GraphType *graph, WorkSpaceType *wspace, int npasses)
+void Mc_KWayFM(CtrlType *ctrl, GraphType *graph, WorkSpaceType *wspace, int npasses)
 {
   int h, i, ii, iii, j, k, c;
   int pass, nvtxs, nedges, ncon;
@@ -127,7 +127,7 @@ void Moc_KWayFM(CtrlType *ctrl, GraphType *graph, WorkSpaceType *wspace, int npa
     oldcut = graph->mincut;
 
     /* check to see if the partitioning is imbalanced */
-    Moc_ComputeParallelBalance(ctrl, graph, graph->where, lbvec);
+    Mc_ComputeParallelBalance(ctrl, graph, graph->where, lbvec);
     ubavg = savg(ncon, ubvec);
     lbavg = savg(ncon, lbvec);
     imbalanced = (lbavg > ubavg) ? 1 : 0;
